---
name: 'Bug Report'
about: 'Report a reproducible bug in the software.'
title: ''
labels: ''
assignees: ''
---

# Impacted versions

* OS Type: Debian/Ubuntu, Centos/Redhat, Arch, Gentoo, Slack, ...
* OS Version: Number or Name
* Database Type: PostgreSQL / MySQL
* Database version: X.y
* Modoboa: X.X.x
* installer used: Yes/No ?
* Webserver: Nginx/Apache

# Steps to reproduce

# Current behavior

<!--

  Explain the behavior you're seeing that you think is a bug, and explain how you
  think things should behave instead.

-->

# Expected behavior

# Video/Screenshot link (optional)

